@@ -13,7 +13,7 @@ kml_layer.Raster <- function(
   ){
 
   require(RSAGA)
-  # get our invisible file connection from custom evnrionment
+  # get our invisible file connection from custom environment
   kml.out <- get("kml.out", envir=plotKML.fileIO)
 
   # Checking the projection 
@@ -29,8 +29,8 @@ kml_layer.Raster <- function(
   }
 
   if(is.call(call[["colour"]])|is.name(call[["colour"]])){
-    x <- data.frame(values(obj))
-    names(x) <- layerNames(obj)
+    x <- data.frame(getValues(obj))
+    names(x) <- names(obj)
     x <- eval(call[["colour"]], x)
     obj <- raster(obj)
     values(obj) <- x
@@ -42,7 +42,7 @@ kml_layer.Raster <- function(
     }
   } else { 
   if(is.character(call[["colour"]])) {
-    i_layer <- which(layerNames(obj) == call[["colour"]])
+    i_layer <- which(names(obj) == call[["colour"]])
     if (nlayers(obj) > 1) {
       obj <- raster(obj, layer = i_layer)
     }
@@ -51,10 +51,9 @@ kml_layer.Raster <- function(
   # TH: this needs to be fixed
   altitude <- charmatch("altitude", names(call))
   if(!is.na(altitude)){
-    altitude <- eval(call[["altitude"]], length(obj))
-    altitude <- kml_altitude(obj, altitude)
+    altitude <- eval(call[["altitude"]], nlayers(obj))
   } else {
-    altitude <- kml_altitude(obj, altitude=NULL)
+    altitude <- rep(.all_kml_aesthetics[["altitude"]], length.out = nlayers(obj))
   }
   altitudeMode <- kml_altitude_mode(altitude, GroundOverlay=TRUE) 
 
@@ -78,7 +77,7 @@ kml_layer.Raster <- function(
   if(is.factor(obj)){
     if(length(labels(obj))==0){
       warning("RasterLayer of type factor missing labels")
-      colour_scale <- colorRampPalette(pal)(length(levels(as.factor(values(obj)))))      
+      colour_scale <- colorRampPalette(pal)(length(levels(as.factor(getValues(obj)))))      
     } else {
       colour_scale <- colorRampPalette(pal)(length(labels(obj)[[1]]))
     }
@@ -135,23 +134,23 @@ kml_layer.Raster <- function(
       legend_name <- paste(strsplit(raster_name, "\\.")[[1]][1], "legend.png", sep="_")      
     }
     if(is.factor(obj)){
-      x <- as.factor(values(obj))
+      x <- as.factor(getValues(obj))
       if(length(labels(obj))==0){
-        levels(x) <- levels(as.factor(values(obj)))
+        levels(x) <- levels(as.factor(getValues(obj)))
       } else {
         levels(x) = labels(obj)[[1]]
       }      
       kml_legend.bar(x = x, legend.file = legend_name, legend.pal = colour_scale)
     } else {
       if(!is.na(charmatch("z.lim", names(call)))){
-        kml_legend.bar(x = values(obj), legend.file = legend_name, legend.pal = colour_scale, z.lim = eval(call[["z.lim"]]))
+        kml_legend.bar(x = getValues(obj), legend.file = legend_name, legend.pal = colour_scale, z.lim = eval(call[["z.lim"]]))
        } else {
-        kml_legend.bar(x = values(obj), legend.file = legend_name, legend.pal = colour_scale)
+        kml_legend.bar(x = getValues(obj), legend.file = legend_name, legend.pal = colour_scale)
        } 
     }
   }
 
-  message("Parsing to KML...")
+  message("Writing to KML...")
   # Folder name
   pl1 = newXMLNode("Folder", parent=kml.out[["Document"]])
   pl2 <- newXMLNode("name", paste(class(obj)), parent = pl1)
@@ -193,4 +192,4 @@ kml_layer.Raster <- function(
 setMethod("kml_layer", "RasterLayer", kml_layer.Raster)
 setMethod("kml_layer", "RasterStack", kml_layer.Raster)
 
-# end of script;
\ No newline at end of file
+# end of script;
